@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : autogen-support.sh
-# Version    : $Id: 6968ff3e214d4669db917e03159347a375702bf0 $
-# Copyright  : 2014-2016 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: 73a28b7fed84152b56fe6576f4a2be103638202d $
+# Copyright  : 2014-2017 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Information: provide support functions to autogen.sh/autogen-all-variants.sh
 #
@@ -25,22 +25,25 @@
 #          GeoIP-1.6.7	# 20161218
 #          GeoIP-1.6.8	# 20161218
 #          GeoIP-1.6.9	# 20161218
+#          GeoIP-1.6.10	# 20170617
+#          GeoIP-1.6.11	# 20170617
 #
 # $BASE_DEVEL_IP2LCATION/   (default if unset: "..")
 #          C-IP2Location-4.0.2  # dropped with version 0.99
 #          ip2location-c-6.0.1
 #          IP2Location-c-6.0.2
 #          ip2location-c-6.0.3	# 20141003
-#          ip2location-c-7.0.0	# 20141003
+##          ip2location-c-7.0.0	# 20141003 DOWNLOAD BROKEN
 #          ip2location-c-7.0.1	# 20150416
 #          ip2location-c-8.0.1	# 20161218
 #          ip2location-c-8.0.2	# 20161218
 #          ip2location-c-8.0.3	# 20161218
+#          ip2location-c-8.0.4	# 20170617
 
 #### Definitions
 
 ## List of GeoIP versions (append newest one rightmost!)
-geoip_versions="1.4.4 1.4.5 1.4.6 1.4.7 1.4.8 1.5.1 1.5.2 1.6.0 1.6.1 1.6.2 1.6.3 1.6.4 1.6.5 1.6.6 1.6.7 1.6.8 1.6.9"
+geoip_versions="1.4.4 1.4.5 1.4.6 1.4.7 1.4.8 1.5.1 1.5.2 1.6.0 1.6.1 1.6.2 1.6.3 1.6.4 1.6.5 1.6.6 1.6.7 1.6.8 1.6.9 1.6.10 1.6.11"
 geoip_url_maxmind="http://geolite.maxmind.com/download/geoip/api/c/"
 geoip_url_github="https://codeload.github.com/maxmind/geoip-api-c/tar.gz/"
 
@@ -82,8 +85,8 @@ geoip_cross_version_test_blacklist() {
 
 
 ## List of IP2Location versions (append newest one rightmost!)
-ip2location_versions="4.0.2 6.0.1 6.0.2 6.0.3 7.0.0 7.0.1 8.0.1 8.0.2 8.0.3"
-ip2location_versions_download="6.0.1 6.0.2 6.0.3 7.0.0 7.0.1 8.0.1 8.0.2 8.0.3"
+ip2location_versions="4.0.2 6.0.1 6.0.2 6.0.3 7.0.1 8.0.1 8.0.2 8.0.3 8.0.4"
+ip2location_versions_download="6.0.1 6.0.2 6.0.3 7.0.1 8.0.1 8.0.2 8.0.3 8.0.4"
 ip2location_url_base="https://www.ip2location.com/downloads/"
 ip2location_url_github="https://codeload.github.com/chrislim2888/IP2Location-C-Library/tar.gz/"
 
@@ -678,8 +681,6 @@ $0 [-A] [-n] [GeoIP|IP2Location [<version>]]
 	IP2Location: $ip2location_versions
 	Prefix '!' means not supported on this platform
 
-	-t  : GeoIP/IP2Location cross-version tests
-
 	-h|?: this online help
 
 	used values from environment (or defaults):
@@ -693,7 +694,7 @@ if [ "$1" != "source" ]; then
 	# use script not only as source (function-mode)
 
 	#### Main
-	while getopts ":ADCXtFnB?h" opt; do
+	while getopts ":ADCXnB?h" opt; do
 		case $opt in
 		    'n')
 			dry_run=1
