@@ -1,15 +1,15 @@
  /*
  * Project       : ipv6calc
  * File          : db_cc_reg_assignment.h
- * Version       : $Id: cdf975a908c8ef223ec7ece7d8bd6ab1147c7df0 $
- * Generated     : Sat Dec 24 15:53:49 2016
+ * Version       : $Id: 703e3ec017f6f1e8c3d11d1c5b34e53f7313f289 $
+ * Generated     : Sun Jun 25 09:47:51 2017
  * Data copyright: RIPE NCC, APNIC, ARIN, LACNIC, AFRINIC
  *
  * Information:
  *  Additional header file for databases/lib/libipv6calc_db_wrapper_BuiltIn.c
  */
 
-static const char *db_cc_registry_status = "AFRINIC/20161224 APNIC/20161223 ARIN/20161224 LACNIC/20161223 RIPENCC/20161223";
+static const char *db_cc_registry_status = "AFRINIC/20170625 APNIC/20170624 ARIN/20170625 LACNIC/20170623 RIPENCC/20170624";
 
 static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "", REGISTRY_ARIN     },
@@ -233,6 +233,7 @@ static const s_cc_reg_assignment cc_reg_assignment[] = {
 	{ "TZ", REGISTRY_AFRINIC  },
 	{ "UA", REGISTRY_RIPENCC  },
 	{ "UG", REGISTRY_AFRINIC  },
+	{ "UM", REGISTRY_ARIN     },
 	{ "US", REGISTRY_ARIN     },
 	{ "UY", REGISTRY_LACNIC   },
 	{ "UZ", REGISTRY_RIPENCC  },
@@ -845,7 +846,7 @@ static const s_cc_index_reg_assignment cc_index_reg_assignment[] = {
 	{ REGISTRY_UNKNOWN  }, //  589  RM
 	{ REGISTRY_RIPENCC  }, //  590  SM
 	{ REGISTRY_RIPENCC  }, //  591  TM
-	{ REGISTRY_UNKNOWN  }, //  592  UM
+	{ REGISTRY_ARIN     }, //  592  UM
 	{ REGISTRY_UNKNOWN  }, //  593  VM
 	{ REGISTRY_UNKNOWN  }, //  594  WM
 	{ REGISTRY_UNKNOWN  }, //  595  XM
