@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : databases/lib/libipv6calc_db_wrapper_BuiltIn.c
- * Version    : $Id: ec9ec92c73343381eb3a979f524e55eb41de41b8 $
- * Copyright  : 2013-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: c9d6dc476e5101f49325c07446b74fbcecf7dce8 $
+ * Copyright  : 2013-2017 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  ipv6calc BuiltIn database wrapper
@@ -77,7 +77,7 @@ int libipv6calc_db_wrapper_BuiltIn_wrapper_init(void) {
 	DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called");
 
 	// add features to implemented
-	wrapper_features_by_source_implemented[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_AS_TO_REGISTRY | IPV6CALC_DB_CC_TO_REGISTRY | IPV6CALC_DB_IPV4_TO_REGISTRY | IPV6CALC_DB_IPV6_TO_REGISTRY | IPV6CALC_DB_IEEE_TO_INFO;
+	wrapper_features_by_source_implemented[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_AS_TO_REGISTRY | IPV6CALC_DB_CC_TO_REGISTRY | IPV6CALC_DB_IPV4_TO_REGISTRY | IPV6CALC_DB_IPV6_TO_REGISTRY | IPV6CALC_DB_IEEE_TO_INFO | IPV6CALC_DB_IPV4_TO_INFO | IPV6CALC_DB_IPV6_TO_INFO;
 
 #ifdef SUPPORT_BUILTIN
 #ifdef SUPPORT_DB_AS_REG
@@ -91,12 +91,12 @@ int libipv6calc_db_wrapper_BuiltIn_wrapper_init(void) {
 #endif
 
 #ifdef SUPPORT_DB_IPV4_REG
-	wrapper_features_by_source[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_IPV4_TO_REGISTRY;
+	wrapper_features_by_source[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_IPV4_TO_REGISTRY | IPV6CALC_DB_IPV4_TO_INFO;
 	builtin_ipv4       = 1;
 #endif
 
 #ifdef SUPPORT_DB_IPV6_REG
-	wrapper_features_by_source[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_IPV6_TO_REGISTRY;
+	wrapper_features_by_source[IPV6CALC_DB_SOURCE_BUILTIN] |= IPV6CALC_DB_IPV6_TO_REGISTRY | IPV6CALC_DB_IPV6_TO_INFO;
 	builtin_ipv6       = 1;
 #endif
 
@@ -643,6 +643,32 @@ int libipv6calc_db_wrapper_BuiltIn_get_row_dbipv4addr_assignment_iana(const uint
 
 	return(0);
 };
+
+
+/*
+ * dbipv4addr_info / get row (callback function for retrieving value from array)
+ */
+int libipv6calc_db_wrapper_BuiltIn_get_row_dbipv4addr_info(const uint32_t row, uint32_t *key_first_00_31_ptr, uint32_t *key_first_32_63_ptr, uint32_t *key_last_00_31_ptr, uint32_t *key_last_32_63_ptr) {
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called fetching row: %lu", (unsigned long int) row);
+
+	if (row >= MAXENTRIES_ARRAY(dbipv4addr_info)) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "row out of range: %lu (maximum: %lu)", (unsigned long int) row, (unsigned long int) MAXENTRIES_ARRAY(dbipv4addr_info) - 1);
+		return(1);
+	};
+
+	*key_first_00_31_ptr = dbipv4addr_info[row].first;
+	*key_last_00_31_ptr  = dbipv4addr_info[row].last;
+	*key_first_32_63_ptr = 0;
+	*key_last_32_63_ptr  = 0;
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Keys for row: %lu key_first_00_31_ptr=%08lx key_last_00_31_ptr=%08lxu",
+		(unsigned long int) row,
+		(unsigned long int) *key_first_00_31_ptr,
+		(unsigned long int) *key_last_00_31_ptr
+	);
+
+	return(0);
+};
 #endif // SUPPORT_DB_IPV4_REG
 
 
@@ -683,6 +709,7 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv4addr(const ipv6calc_ipv4a
 	};
 
 	if (result == IPV4_ADDR_REGISTRY_UNKNOWN) {
+		// IANA fallback
 		DEBUGPRINT_NA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Nothing found in dbipv4addr_assignment, fallback now to dbipv4addr_assignment_iana");
 
 		match = libipv6calc_db_wrapper_get_entry_generic(
@@ -713,6 +740,52 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv4addr(const ipv6calc_ipv4a
 };
 
 
+/*
+ * get info of an IPv4 address
+ *
+ * in:  ipv4addr = IPv4 address structure
+ * in:  char* and size to fill
+ * out: 0 = found, -1 = no result
+ */
+int libipv6calc_db_wrapper_BuiltIn_info_by_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, char *string, const size_t string_len) {
+	uint32_t ipv4 = ipv4addr_getdword(ipv4addrp);
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Given IPv4 address: %08x", (unsigned int) ipv4);
+
+	int result = -1;
+
+#ifdef SUPPORT_DB_IPV4_REG
+	int match = -1;
+
+	match = libipv6calc_db_wrapper_get_entry_generic(
+		NULL,							// pointer to data
+		IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_ARRAY,			// type of data_ptr
+		IPV6CALC_DB_LOOKUP_DATA_KEY_TYPE_FIRST_LAST,		// key type
+		0,							// key format (not relevant)
+		32,							// key length
+		IPV6CALC_DB_LOOKUP_DATA_SEARCH_TYPE_BINARY,		// search type
+		MAXENTRIES_ARRAY(dbipv4addr_info),			// number of rows
+		ipv4,							// lookup key MSB
+		0,							// lookup key LSB
+		NULL,							// data ptr (not used in IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_ARRAY)
+		libipv6calc_db_wrapper_BuiltIn_get_row_dbipv4addr_info	// function pointer
+	);
+
+	if (match > -1) {
+		snprintf(string, string_len, "%s", dbipv4addr_info[match].info);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Finished with success result (dbipv4addr_info): match=%d info=\"%s\"", match, string);
+		BUILTIN_DB_USAGE_MAP_TAG(BUILTIN_DB_IPV4_REGISTRY);
+		result = 0;
+	};
+
+#else  // SUPPORT_DB_IPV4_REG
+	snprintf(string, string_len, "%s", "");
+#endif // SUPPORT_DB_IPV4_REG
+
+	return(result);
+};
+
+
 #ifdef SUPPORT_DB_IPV6_REG
 /*
  * dbipv6addr_assignment / get row (callback function for retrieving value from array)
@@ -741,6 +814,35 @@ int libipv6calc_db_wrapper_BuiltIn_get_row_dbipv6addr_assignment(const uint32_t
 
 	return(dbipv6addr_assignment[row].prefixlength);
 };
+
+
+/*
+ * dbipv6addr_info / get row (callback function for retrieving value from array)
+ */
+int libipv6calc_db_wrapper_BuiltIn_get_row_dbipv6addr_info(const uint32_t row, uint32_t *key_base_00_31_ptr, uint32_t *key_base_32_63_ptr, uint32_t *key_mask_00_31_ptr, uint32_t *key_mask_32_63_ptr) {
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Called fetching row: %lu", (unsigned long int) row);
+
+	if (row >= MAXENTRIES_ARRAY(dbipv6addr_info)) {
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "row out of range: %lu (maximum: %lu)", (unsigned long int) row, (unsigned long int) MAXENTRIES_ARRAY(dbipv6addr_info) - 1);
+		return(-1);
+	};
+
+	*key_base_00_31_ptr = dbipv6addr_info[row].ipv6addr_00_31;
+	*key_base_32_63_ptr = dbipv6addr_info[row].ipv6addr_32_63;
+	*key_mask_00_31_ptr = dbipv6addr_info[row].ipv6mask_00_31;
+	*key_mask_32_63_ptr = dbipv6addr_info[row].ipv6mask_32_63;
+
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Keys for row: %lu key_base_00_31_ptr=%08lx key_base_32_63_ptr=%08lx key_mask_00_31_ptr=%08lxu key_mask_32_63_ptr=%08lxu seqlongest=%d",
+		(unsigned long int) row,
+		(unsigned long int) *key_base_00_31_ptr,
+		(unsigned long int) *key_base_32_63_ptr,
+		(unsigned long int) *key_mask_00_31_ptr,
+		(unsigned long int) *key_mask_32_63_ptr,
+		dbipv6addr_info[row].prefixlength
+	);
+
+	return(dbipv6addr_info[row].prefixlength);
+};
 #endif // SUPPORT_DB_IPV6_REG
 
 
@@ -756,7 +858,7 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv6addr(const ipv6calc_ipv6a
 	
 	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Given ipv6 prefix: %08x%08x", (unsigned int) ipv6_00_31, (unsigned int) ipv6_32_63);
 
-	if ((ipv6addrp->scope & IPV6_NEW_ADDR_6BONE) != 0) {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_6BONE) != 0) {
 		return(IPV6_ADDR_REGISTRY_6BONE);
 	};
 
@@ -788,4 +890,51 @@ int libipv6calc_db_wrapper_BuiltIn_registry_num_by_ipv6addr(const ipv6calc_ipv6a
 	return(result);
 };
 
+
+/*
+ * get info of an IPv6 address
+ *
+ * in:  ipv6addr = IPv6 address structure
+ * in:  char* and size to fill
+ * out: 0 = found, -1 = no result
+ */
+int libipv6calc_db_wrapper_BuiltIn_info_by_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp, char *string, const size_t string_len) {
+	uint32_t ipv6_00_31 = ipv6addr_getdword(ipv6addrp, 0);
+	uint32_t ipv6_32_63 = ipv6addr_getdword(ipv6addrp, 1);
+	
+	DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Given ipv6 prefix: %08x%08x", (unsigned int) ipv6_00_31, (unsigned int) ipv6_32_63);
+
+	int result = -1;
+
+#ifdef SUPPORT_DB_IPV6_REG
+	int match = -1;
+
+	match = libipv6calc_db_wrapper_get_entry_generic(
+		NULL,							// pointer to data
+		IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_ARRAY,			// type of data_ptr
+		IPV6CALC_DB_LOOKUP_DATA_KEY_TYPE_BASE_MASK,		// key type
+		0,							// key format (not relevant)
+		64,							// key length
+		IPV6CALC_DB_LOOKUP_DATA_SEARCH_TYPE_BINARY,		// search type
+		MAXENTRIES_ARRAY(dbipv6addr_info),			// number of rows
+		ipv6_00_31,						// lookup key MSB
+		ipv6_32_63,						// lookup key LSB
+		NULL,							// data ptr (not used in IPV6CALC_DB_LOOKUP_DATA_PTR_TYPE_ARRAY)
+		libipv6calc_db_wrapper_BuiltIn_get_row_dbipv6addr_info	// function pointer
+	);
+
+	if (match > -1) {
+		snprintf(string, string_len, "%s", dbipv6addr_info[match].info);
+		DEBUGPRINT_WA(DEBUG_libipv6calc_db_wrapper_BuiltIn, "Finished with success result (dbipv6addr_info): match=%d info=\"%s\"", match, string);
+		BUILTIN_DB_USAGE_MAP_TAG(BUILTIN_DB_IPV6_REGISTRY);
+		result = 0;
+	};
+
+#else  // SUPPORT_DB_IPV6_REG
+	snprintf(string, string_len, "%s", "");
+#endif // SUPPORT_DB_IPV6_REG
+
+	return(result);
+};
+
 #endif		// SUPPORT_BUILTIN
