@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc/ipv6calc.c
- * Version    : $Id: 800c6e7b79c6b16992852af91299e830003f9d90 $
- * Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 2eb8ebcd4bae67ccfbd0cb10edab2d7e4ebc6cc7 $
+ * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -205,9 +205,13 @@ int main(int argc, char *argv[]) {
 	ipv6calc_common_options_from_env(longopts, &ipv6calc_anon_set);
 	
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Parsing option: 0x%08x", i);
+		DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Parsing option: 0x%08x (%d: %s)", i, optind, argv[optind - 1]);
 
-		if ((i == '?') && (optopt != 0)) {
+		if ((i == '?') && (strcmp(argv[optind - 1], "-?") != 0)) {
+			exit(EXIT_FAILURE);
+		};
+
+		if (i == ':') {
 			exit(EXIT_FAILURE);
 		};
 
@@ -463,6 +467,7 @@ int main(int argc, char *argv[]) {
 
 				// save pointer for later
 				input_a[a] = optarg;
+				break;
 
 			/* format options */
 			case 'C':
@@ -702,12 +707,29 @@ int main(int argc, char *argv[]) {
 		feature_kp = 1;
 	};
 
+	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); // ipv6calc_debug usage ok
+
+	/* do work depending on selection */
+	if ((command & CMD_printversion) != 0) {
+		if ((command & CMD_printversion_verbose) != 0) {
+			printversion_verbose(((command & CMD_printversion_verbose2) !=0) ? LEVEL_VERBOSE2 : LEVEL_VERBOSE);
+		} else {
+			printversion();
+		};
+
+		if ((command & CMD_printhelp) != 0) {
+			printversion_help();
+		};
+
+		exit(EXIT_SUCCESS);
+	};
+
 	/* print help handling */
 	if ((outputtype_given == 1) && (command & CMD_printhelp)) {
 		command = CMD_printexamples;
 	};
 
-	if (command == CMD_printhelp) {
+	if (command & CMD_printhelp) {
 		if ( (outputtype == FORMAT_undefined) && (inputtype == FORMAT_undefined) && (action == ACTION_undefined)) {
 			ipv6calc_printhelp(longopts, ipv6calc_longopts_shortopts_map);
 			exit(EXIT_FAILURE);
@@ -740,23 +762,6 @@ int main(int argc, char *argv[]) {
 		exit(EXIT_FAILURE);
 	};
 
-	DEBUGPRINT_WA(DEBUG_ipv6calc_general, "Debug value:%08lx command:%08lx inputtype:%08lx outputtype:%08lx action:%08lx formatoptions:%08lx", (unsigned long) ipv6calc_debug, (unsigned long) command, (unsigned long) inputtype, (unsigned long) outputtype, (unsigned long) action, (unsigned long) formatoptions); // ipv6calc_debug usage ok
-
-	/* do work depending on selection */
-	if ((command & CMD_printversion) != 0) {
-		if ((command & CMD_printversion_verbose) != 0) {
-			printversion_verbose(((command & CMD_printversion_verbose2) !=0) ? LEVEL_VERBOSE2 : LEVEL_VERBOSE);
-		} else {
-			printversion();
-		};
-
-		if ((command & CMD_printhelp) != 0) {
-			printversion_help();
-		};
-
-		exit(EXIT_SUCCESS);
-	};
-
 	if (action == ACTION_anonymize) {
 		/* check requirements */
 		if (libipv6calc_anon_supported(&ipv6calc_anon_set) == 0) {
@@ -1173,6 +1178,8 @@ PIPE_input:
 	DEBUGPRINT_NA(DEBUG_ipv6calc_general, "Start of postprocessing input");
 
 	if (ipv4addr.flag_valid == 1) {
+		ipv4addr_settype(&ipv4addr, 1); /* Set typeinfo */
+
 		/* force prefix */
 		if ((formatoptions & (FORMATOPTION_forceprefix)) != 0) {
 			ipv4addr.flag_prefixuse = 1;
@@ -1181,6 +1188,8 @@ PIPE_input:
 	};
 
 	if (ipv6addr.flag_valid == 1) {
+		ipv6addr_settype(&ipv6addr, 1); /* Set typeinfo */
+
 		/* honor 6rd prefix length option */
 		if (ipv6rd_prefixlength > 0) {
 			ipv6addr.typeinfo2 |= IPV6_ADDR_TYPE2_6RD;
