@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc.h
- * Version    : $Id: ipv6calc.h,v 1.16 2013/10/28 07:25:31 ds6peter Exp $
- * Copyright  : 2001-2013 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 6107c9e81352a59a191e3f256fdb98cd75750dd0 $
+ * Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Main header file
@@ -27,3 +27,6 @@
 extern int feature_zeroize;
 extern int feature_anon;
 extern int feature_kp;
+
+extern char showinfo_machine_readable_filter[];
+extern int showinfo_machine_readable_filter_used;
