@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6calc
  * File       : ipv6calchelp_local.c
- * Version    : $Id: 4d038d5dad0fc91f2c35c90021b439a10e12b41f $
- * Copyright  : 2013-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: d06e7613875a369e5c947cd756743275425c26d3 $
+ * Copyright  : 2013-2017 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -54,13 +54,13 @@ void printversion_help(void) {
 
 	fprintf(stderr, "\n");
 
-	fprintf(stderr, "Explanation of available(+)/possible(-) feature tokens\n");
+	fprintf(stderr, "Explanation of available(x)/possible(o) feature tokens\n");
 
 	libipv6calc_db_wrapper_features_help();
 
-	fprintf(stderr, "%-22s%c %s\n", "ANON_ZEROISE", (feature_zeroize == 1)? '+' : '-', "Anonymization method 'zeroize'");
-	fprintf(stderr, "%-22s%c %s\n", "ANON_ANONYMIZE", (feature_anon == 1) ? '+' : '-', "Anonymization method 'anonymize'");
-	fprintf(stderr, "%-22s%c %s\n", "ANON_KEEP-TYPE-ASN-CC", (feature_kp == 1) ? '+' : '-', "Anonymization method 'keep-type-asn-cc'");
+	fprintf(stderr, "%-22s%c %s\n", "ANON_ZEROISE", (feature_zeroize == 1)? 'x' : 'o', "Anonymization method 'zeroize'");
+	fprintf(stderr, "%-22s%c %s\n", "ANON_ANONYMIZE", (feature_anon == 1) ? 'x' : 'o', "Anonymization method 'anonymize'");
+	fprintf(stderr, "%-22s%c %s\n", "ANON_KEEP-TYPE-ASN-CC", (feature_kp == 1) ? 'x' : 'o', "Anonymization method 'keep-type-asn-cc'");
 
 	fprintf(stderr, "\n");
 };
