@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: c168105b62fcbf4d77f894dd063e54f4eb9040aa $
- * Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 5b5084bd6182191f9c395977f472355318aa05ef $
+ * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Function to show information about a given IPv6 address
@@ -136,6 +136,16 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " DBIP_COUNTRY_SHORT=.. .       : Country code of IP address\n");
 	fprintf(stderr, " DBIP_CITY=...                 : City of IP address\n");
 	fprintf(stderr, " DBIP_REGION=...               : Region of IP address\n");
+	fprintf(stderr, " DBIP_DISTRICT=...             : District of IP address\n");
+	fprintf(stderr, " DBIP_ZIPCODE=...              : ZIP code of IP address\n");
+	fprintf(stderr, " DBIP_GEONAME_ID=...           : GeoName ID of IP address\n");
+	fprintf(stderr, " DBIP_LATITUDE=...             : Latitude of IP address\n");
+	fprintf(stderr, " DBIP_LONGITUDE=...            : Longitude of IP address\n");
+	fprintf(stderr, " DBIP_TIMEZONE=...             : Time zone of IP address\n");
+	fprintf(stderr, " DBIP_TIMEZONE_NAME=...        : Time zone name of IP address\n");
+	fprintf(stderr, " DBIP_NETSPEED=...             : Net speed of IP address\n");
+	fprintf(stderr, " DBIP_ISP=...                  : ISP of IP address\n");
+	fprintf(stderr, " DBIP_ORGNAME=...              : Organization name of IP address\n");
 	fprintf(stderr, " DBIP_DATABASE_INFO=.. .       : Information about the used databases\n");
 #endif
 #ifdef SUPPORT_EXTERNAL
@@ -723,6 +733,8 @@ static void print_geoip(const char *addrstring, const uint32_t formatoptions, co
 static void print_dbip(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatoptions, const char *additionalstring) {
 	DEBUGPRINT_NA(DEBUG_showinfo, "Called");
 
+#define TEST_DBIP_AVAILABLE(v)	((v != NULL) && (strlen(v) > 0))
+
 #define HUMAN_READABLE_DBIP(name, value) \
 				if (strlen(additionalstring) > 0) { \
 					fprintf(stdout, "DB-IP.com reports for %s %s: %s\n", additionalstring, name, value); \
@@ -737,41 +749,122 @@ static void print_dbip(const ipv6calc_ipaddr *ipaddrp, const uint32_t formatopti
 
 	int ret;
 
-	char returnedCountry[256] = "";
-	char returnedCity[256] = "";
-	char returnedRegion[256] = "";
+	DBIP_Record record;
+	char tempstring[NI_MAXHOST];
 
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable);
 
-	ret = libipv6calc_db_wrapper_DBIP_wrapper_country_code_by_addr(ipaddrp, returnedCountry, sizeof(returnedCountry));
-	if ((ret == 0) && (strlen(returnedCountry) > 0)) {
-		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d country database result", ipaddrp->proto);
+	/* get all information */
+	ret = libipv6calc_db_wrapper_DBIP_all_by_addr(ipaddrp, &record);
 
-		if ( machinereadable != 0 ) {
-			printout2("DBIP_COUNTRY_SHORT", additionalstring, returnedCountry, formatoptions);
-		} else {
-			HUMAN_READABLE_DBIP("Country Code", returnedCountry)
+	if (ret == 0) {
+		if (TEST_DBIP_AVAILABLE(record.country)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_COUNTRY_SHORT", additionalstring, record.country, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Country Code", record.country)
+			};
 		};
-	};
 
-	ret = libipv6calc_db_wrapper_DBIP_wrapper_city_by_addr(ipaddrp, returnedCity, sizeof(returnedCity), returnedRegion, sizeof(returnedRegion));
-	if ((ret == 0) && (strlen(returnedCity) > 0)) {
-		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d city database result", ipaddrp->proto);
-
-		if ( machinereadable != 0 ) {
-			printout2("DBIP_CITY", additionalstring, returnedCity, formatoptions);
-		} else {
-			HUMAN_READABLE_DBIP("City", returnedCity)
+		if (TEST_DBIP_AVAILABLE(record.stateprov)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_REGION", additionalstring, record.stateprov, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Region", record.stateprov)
+			};
 		};
-	};
 
-	if ((ret == 0) && (strlen(returnedRegion) > 0)) {
-		DEBUGPRINT_WA(DEBUG_showinfo, "DBIP IPv%d region database result", ipaddrp->proto);
+		if (TEST_DBIP_AVAILABLE(record.district)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_DISTRICT", additionalstring, record.district, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("District", record.district)
+			};
+		};
 
-		if ( machinereadable != 0 ) {
-			printout2("DBIP_REGION", additionalstring, returnedRegion, formatoptions);
-		} else {
-			HUMAN_READABLE_DBIP("Region", returnedRegion)
+		if (TEST_DBIP_AVAILABLE(record.city)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_CITY", additionalstring, record.city, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("City", record.city)
+			};
+		};
+
+		if (TEST_DBIP_AVAILABLE(record.isp_name)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_ISP", additionalstring, record.isp_name, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("ISP", record.isp_name)
+			};
+		};
+
+		if (record.latitude != 0) {
+			snprintf(tempstring, sizeof(tempstring), "%f", record.latitude);
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_LATITUDE", additionalstring, tempstring, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Latitude", tempstring)
+			};
+		};
+
+		if (record.longitude != 0) {
+			snprintf(tempstring, sizeof(tempstring), "%f", record.longitude);
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_LONGITUDE", additionalstring, tempstring, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Longitude", tempstring)
+			};
+		};
+
+		if (TEST_DBIP_AVAILABLE(record.zipcode)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_ZIPCODE", additionalstring, record.zipcode, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("ZIP Code", record.zipcode)
+			};
+		};
+
+		if (TEST_DBIP_AVAILABLE(record.timezone_name)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_TIMEZONE_NAME", additionalstring, record.timezone_name, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Time Zone Name", record.timezone_name)
+			};
+
+			// timezone_name set -> timezone_offset considered as valid
+			// convert timezone offset into human readable value
+			snprintf(tempstring, sizeof(tempstring), "%+03d:%02d", (int) record.timezone_offset, (int) ((record.timezone_offset - (int) record.timezone_offset) * 60));
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_TIMEZONE", additionalstring, tempstring, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Time Zone", tempstring)
+			};
+
+		};
+
+		if (TEST_DBIP_AVAILABLE(record.connection_type)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_NETSPEED", additionalstring, record.connection_type, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Network Speed", record.connection_type)
+			};
+		};
+
+		if (record.geoname_id != 0) {
+			snprintf(tempstring, sizeof(tempstring), "%d", record.geoname_id);
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_GEONAME_ID", additionalstring, tempstring, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Geoname ID", tempstring)
+			};
+		};
+
+		if (TEST_DBIP_AVAILABLE(record.organization_name)) {
+			if ( machinereadable != 0 ) {
+				printout2("DBIP_ORGNAME", additionalstring, record.organization_name, formatoptions);
+			} else {
+				HUMAN_READABLE_DBIP("Organization Name", record.organization_name)
+			};
 		};
 	};
 };
@@ -812,12 +905,11 @@ static void print_external(const ipv6calc_ipaddr *ipaddrp, const uint32_t format
 
 /* print IPv4 address */
 static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t formatoptions, const char *string) {
-	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
+	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", tempstring3[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
 	char tempipv4string[NI_MAXHOST] = "";
 	char embeddedipv4string[NI_MAXHOST] = "";
 	uint32_t machinereadable = (formatoptions & FORMATOPTION_machinereadable), as_num32 = ASNUM_AS_UNKNOWN;
-	int retval, i, j, retval_anon = 1;
-	uint32_t typeinfo;
+	int retval, i, j, retval_anon = 1, r;
 	ipv6calc_ipv4addr ipv4addr_anon, *ipv4addr_anon_ptr;
 	uint16_t cc_index = COUNTRYCODE_INDEX_UNKNOWN;
 	char *as_text = NULL;
@@ -828,9 +920,10 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 	ipv4addr_anon_ptr = &ipv4addr_anon;
 
-	typeinfo = ipv4addr_gettype(ipv4addrp);
-
-	DEBUGPRINT_WA(DEBUG_showinfo, "result of 'ipv4addr_gettype': 0x%08x", (unsigned int) typeinfo);
+	if (ipv4addrp->flag_typeinfo == 0) {
+		fprintf(stderr, "FATAL error, typeinfo not valid - FIX CODE of caller\n");
+		exit(2);
+	};
 
 	retval = libipv4addr_ipv4addrstruct_to_string(ipv4addrp, tempipv4string, sizeof(tempipv4string), 0);
 	if ( retval != 0 ) {
@@ -846,7 +939,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 	ipv4addr_copy(ipv4addr_anon_ptr, ipv4addrp); /* copy structure */
 
-	if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
+	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 		retval_anon = libipv4addr_anonymize(ipv4addr_anon_ptr, ipv6calc_anon_set.mask_ipv4, ipv6calc_anon_set.method);
 
 		if (retval_anon == 0) {
@@ -859,7 +952,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		};
 	};
 	
-	if ( machinereadable != 0 ) {
+	if (machinereadable != 0) {
 		/* given source string */
 		if ((string != NULL) && (strlen(string) > 0)) {
 			printout2("IPV4_SOURCE", embeddedipv4string, string, formatoptions);
@@ -868,7 +961,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		/* address */
 		printout2("IPV4", embeddedipv4string, tempipv4string, formatoptions);
 
-		if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {	
+		if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 			if (retval_anon == 0 ) {	
 				/* anonymized address */
 				printout2("IPV4_ANON", embeddedipv4string, tempstring2, formatoptions);
@@ -888,7 +981,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 		snprintf(tempstring, sizeof(tempstring), "%s", "");
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
-			if ( (typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0 ) {
+			if ((ipv4addrp->typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0) {
 				if (j != 0) {
 					snprintf(helpstring, sizeof(helpstring), "%s,", tempstring);
 					snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
@@ -910,7 +1003,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		fprintf(stdout, "IPv4 address type: ");
 		j = 0;
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv4addrtypestrings); i++ ) {
-			if ( (typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0 ) {
+			if ((ipv4addrp->typeinfo & ipv6calc_ipv4addrtypestrings[i].number) != 0) {
 				if ( j != 0 ) { fprintf(stdout, ", "); };
 				fprintf(stdout, "%s", ipv6calc_ipv4addrtypestrings[i].token);
 				j = 1;
@@ -919,10 +1012,10 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 		fprintf(stdout, "\n");
 	};	
 
-	if ((typeinfo & (IPV4_ADDR_GLOBAL)) != 0) {
+	if ((ipv4addrp->typeinfo & (IPV4_ADDR_GLOBAL)) != 0) {
 		/* get AS Information */
 		as_num32 = libipv4addr_as_num32_by_addr(ipv4addrp);
-		if ((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
+		if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) {
 			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV4_TO_AS) == 1) {
 				as_text = libipv6calc_db_wrapper_as_text_by_addr(&ipaddr);
 			};
@@ -986,15 +1079,23 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 
 	DEBUGPRINT_NA(DEBUG_showinfo, "get registry");
 
-	if ((typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
+	if ((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) != 0) {
 		registry = libipv4addr_registry_num_by_addr(ipv4addrp);
 		snprintf(tempstring2, sizeof(tempstring2), "%s", libipv6calc_registry_string_by_num(registry));
 	} else {
 		libipv6calc_db_wrapper_registry_string_by_ipv4addr(ipv4addrp, tempstring, sizeof(tempstring));
 		snprintf(tempstring2, sizeof(tempstring2), "%s", tempstring);
+
+		DEBUGPRINT_NA(DEBUG_showinfo, "try to get additional information");
+		r = libipv6calc_db_wrapper_info_by_ipv4addr(ipv4addrp, tempstring3, sizeof(tempstring3));
+		if (r == 0) {
+			// info found, append to registry
+			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			snprintf(tempstring2, sizeof(tempstring2), "%s(%s)", tempstring, tempstring3);
+		};
 	};
 
-	if ( machinereadable != 0 ) {
+	if (machinereadable != 0) {
 		printout2("IPV4_REGISTRY", embeddedipv4string, tempstring2, formatoptions);
 	} else {
 		if (strlen(embeddedipv4string) > 0) {
@@ -1005,7 +1106,7 @@ static void print_ipv4addr(const ipv6calc_ipv4addr *ipv4addrp, const uint32_t fo
 	};
 
 
-	if (((typeinfo & IPV4_ADDR_ANONYMIZED) == 0) && ((typeinfo & IPV4_ADDR_GLOBAL) != 0)) {
+	if (((ipv4addrp->typeinfo & IPV4_ADDR_ANONYMIZED) == 0) && ((ipv4addrp->typeinfo & IPV4_ADDR_GLOBAL) != 0)) {
 #ifdef SUPPORT_IP2LOCATION
 		/* IP2Location information */
 		print_ip2location(tempipv4string, formatoptions, embeddedipv4string, 4);
@@ -1131,7 +1232,8 @@ static void print_eui48(const ipv6calc_macaddr *macaddrp, const uint32_t formato
 		for ( i = 0; i <= 3; i++ ) {
 			ipv4addr_setoctet(&ipv4addr, (unsigned int) i, (unsigned int) macaddrp->addr[i + 2]);
 		};
-		ipv4addr.scope = ipv4addr_gettype(&ipv4addr);
+		ipv4addr_settype(&ipv4addr, 1);
+		ipv4addr.flag_valid = 1;
 
 		if ( machinereadable != 0 ) {
 			/* no additional hint */
@@ -1202,15 +1304,14 @@ static void print_eui64(const ipv6calc_eui64addr *eui64addrp, const uint32_t for
  * ret: ==0: ok, !=0: error
  */
 int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t formatoptions) {
-	int retval = 1, i, j, flag_prefixuse, registry, r, retval_anon = 1;;
-	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
+	int retval = 1, i, j, flag_prefixuse, registry, r, retval_anon = 1;
+	char tempstring[NI_MAXHOST] = "", tempstring2[NI_MAXHOST] = "", tempstring3[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
 	char ipv6addrstring[NI_MAXHOST] = "";
 	ipv6calc_ipv6addr ipv6addr, ipv6addr_anon, *ipv6addrp, *ipv6addr_anon_ptr;
 	ipv6calc_ipv4addr ipv4addr, ipv4addr2;
 	ipv6calc_macaddr macaddr;
 	ipv6calc_eui64addr eui64addr;
 	uint16_t port;
-	uint32_t typeinfo, typeinfo2;
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 	uint32_t payload, as_num32, cc_index;
 	char *as_text = NULL;
@@ -1222,15 +1323,22 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	ipv6addrp = &ipv6addr;
 	ipv6addr_copy(ipv6addrp, ipv6addrp1); /* copy structure */
 
-	typeinfo = ipv6addr_gettype(ipv6addrp);
-	typeinfo2 = ipv6addrp->typeinfo2;
+	if (ipv6addrp->flag_typeinfo == 0) {
+		fprintf(stderr, "FATAL error, typeinfo not valid - FIX CODE of caller\n");
+		exit(2);
+	};
 
-	DEBUGPRINT_WA(DEBUG_showinfo, "%08x-%0x8 (result of 'ipv6addr_gettype')", (unsigned int) typeinfo, (unsigned int) typeinfo2);
+	DEBUGPRINT_WA(DEBUG_showinfo, "typeinfo 0x%08x-0x%08x (from given address)", (unsigned int) ipv6addrp->typeinfo, (unsigned int) ipv6addrp->typeinfo2);
 
 	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
-		DEBUGPRINT_WA(DEBUG_showinfo, "test: %08x : %s", (unsigned int) ipv6calc_ipv6addrtypestrings[i].number, ipv6calc_ipv6addrtypestrings[i].token);
+		DEBUGPRINT_WA(DEBUG_showinfo, "test1: %08x : %s", (unsigned int) ipv6calc_ipv6addrtypestrings[i].number, ipv6calc_ipv6addrtypestrings[i].token);
 	};	
 
+	for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
+		DEBUGPRINT_WA(DEBUG_showinfo, "test2: %08x : %s", (unsigned int) ipv6calc_ipv6addr_type2_strings[i].number, ipv6calc_ipv6addr_type2_strings[i].token);
+	};
+
+
 	/* get full uncompressed IPv6 address */
 	flag_prefixuse = ipv6addrp->flag_prefixuse;
 	ipv6addrp->flag_prefixuse = 0;
@@ -1245,7 +1353,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	CONVERT_IPV6ADDRP_IPADDR(ipv6addrp, ipaddr);
 
-	if ((typeinfo & (IPV6_ADDR_ANONYMIZED_PREFIX | IPV6_ADDR_ANONYMIZED_IID)) == 0 ) {
+	if ((ipv6addrp->typeinfo & (IPV6_ADDR_ANONYMIZED_PREFIX | IPV6_ADDR_ANONYMIZED_IID)) == 0 ) {
 		ipv6addr_copy(ipv6addr_anon_ptr, ipv6addrp); /* copy structure */
 
 		retval_anon = libipv6addr_anonymize(ipv6addr_anon_ptr, &ipv6calc_anon_set);
@@ -1263,7 +1371,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	if ( machinereadable != 0 ) {
 		printout("IPV6", ipv6addrstring, formatoptions);
 	
-		if ((typeinfo & (IPV6_ADDR_ANONYMIZED_PREFIX | IPV6_ADDR_ANONYMIZED_IID | IPV6_ADDR_LOOPBACK)) == 0 ) {
+		if ((ipv6addrp->typeinfo & (IPV6_ADDR_ANONYMIZED_PREFIX | IPV6_ADDR_ANONYMIZED_IID | IPV6_ADDR_LOOPBACK)) == 0 ) {
 			if (retval_anon == 0) {
 				printout("IPV6_ANON", tempstring2, formatoptions);
 			} else {
@@ -1280,7 +1388,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		j = 0;
 		snprintf(tempstring, sizeof(tempstring), "%s", "");
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
-			if ( (typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
+			if ((ipv6addrp->typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0) {
 				if (j != 0) {
 					snprintf(helpstring, sizeof(helpstring), "%s,", tempstring);
 					snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
@@ -1291,7 +1399,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 			};
 		};
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
-			if ( (typeinfo2 & ipv6calc_ipv6addr_type2_strings[i].number) != 0 ) {
+			if ((ipv6addrp->typeinfo2 & ipv6calc_ipv6addr_type2_strings[i].number) != 0) {
 				if (j != 0) {
 					snprintf(helpstring, sizeof(helpstring), "%s,", tempstring);
 					snprintf(tempstring, sizeof(tempstring), "%s", helpstring);
@@ -1306,16 +1414,23 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		fprintf(stdout, "Address type: ");
 		j = 0;
 		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addrtypestrings); i++ ) {
-			if ( (typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0 ) {
+			if ((ipv6addrp->typeinfo & ipv6calc_ipv6addrtypestrings[i].number) != 0) {
 				if ( j != 0 ) { fprintf(stdout, ", "); };
 				fprintf(stdout, "%s", ipv6calc_ipv6addrtypestrings[i].token);
 				j = 1;
 			};
 		};
+		for (i = 0; i < MAXENTRIES_ARRAY(ipv6calc_ipv6addr_type2_strings); i++ ) {
+			if ((ipv6addrp->typeinfo2 & ipv6calc_ipv6addr_type2_strings[i].number) != 0) {
+				if ( j != 0 ) { fprintf(stdout, ", "); };
+				fprintf(stdout, "%s", ipv6calc_ipv6addr_type2_strings[i].token);
+				j = 1;
+			};
+		};
 		fprintf(stdout, "\n");
 	};
 
-	if ((typeinfo & (IPV6_NEW_ADDR_AGU)) != 0 ) {
+	if ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_AGU)) != 0) {
 		/* CountryCode */
 		DEBUGPRINT_NA(DEBUG_showinfo, "get country code");
 		cc_index = libipv6addr_cc_index_by_addr(ipv6addrp, &data_source);
@@ -1348,7 +1463,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 		/* AS */
 		DEBUGPRINT_NA(DEBUG_showinfo, "get AS number/text");
-		if ((typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
+		if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) == 0) {
 			if (libipv6calc_db_wrapper_has_features(IPV6CALC_DB_IPV6_TO_AS) == 1) {
 				as_text = libipv6calc_db_wrapper_as_text_by_addr(&ipaddr);
 			};
@@ -1384,13 +1499,21 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 	/* IPv6 Registry */
 	DEBUGPRINT_NA(DEBUG_showinfo, "get registry");
-	if (((typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) != 0) \
-		&& ((ipv6addrp->scope & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) == 0)) {
+	if (((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_PREFIX) != 0) \
+		&& ((ipv6addrp->typeinfo & IPV6_ADDR_HAS_PUBLIC_IPV4_IN_PREFIX) == 0)) {
 		registry = libipv6addr_registry_num_by_addr(ipv6addrp);
 		snprintf(tempstring2, sizeof(tempstring2), "%s", libipv6calc_registry_string_by_num(registry));
 	} else {
 		libipv6calc_db_wrapper_registry_string_by_ipv6addr(ipv6addrp, tempstring, sizeof(tempstring));
 		snprintf(tempstring2, sizeof(tempstring2), "%s", tempstring);
+
+		DEBUGPRINT_NA(DEBUG_showinfo, "try to get additional information");
+		r = libipv6calc_db_wrapper_info_by_ipv6addr(ipv6addrp, tempstring3, sizeof(tempstring3));
+		if (r == 0) {
+			// info found, append to registry
+			snprintf(tempstring, sizeof(tempstring), "%s", tempstring2);
+			snprintf(tempstring2, sizeof(tempstring2), "%s(%s)", tempstring, tempstring3);
+		};
 	};
 
 	if ( machinereadable != 0 ) {
@@ -1401,7 +1524,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 
 	/* 6to4 */
-	if ( (typeinfo & IPV6_NEW_ADDR_6TO4) != 0 ) {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_6TO4) != 0) {
 		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
@@ -1428,7 +1551,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* Teredo */
-	if ( (typeinfo & IPV6_NEW_ADDR_TEREDO) != 0 ) {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_TEREDO) != 0) {
 		/* extract Teredo client IPv4 address */
 		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
@@ -1468,7 +1591,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* 6rd */
-	if ((typeinfo2 & IPV6_ADDR_TYPE2_6RD) != 0) {
+	if ((ipv6addrp->typeinfo2 & IPV6_ADDR_TYPE2_6RD) != 0) {
 		DEBUGPRINT_WA(DEBUG_showinfo, "6rd found with prefix: %d", ipv6addrp->prefix2length);
 		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_PREFIX2_LENGTH);
 
@@ -1496,7 +1619,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* NAT64 */
-	if ( (typeinfo & IPV6_NEW_ADDR_NAT64) != 0 )  {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_NAT64) != 0)  {
 		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
@@ -1509,11 +1632,11 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* SLA prefix included? */
-	if ( ((typeinfo & ( IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0)) {
+	if (((ipv6addrp->typeinfo & ( IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) && ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0)) {
 		uint16_t sla = ipv6addr_getword(ipv6addrp, 3);
 		uint16_t sla_mask = 0xffff;
 
-		if ((typeinfo2 & IPV6_ADDR_TYPE2_6RD) != 0) {
+		if ((ipv6addrp->typeinfo2 & IPV6_ADDR_TYPE2_6RD) != 0) {
 			DEBUGPRINT_WA(DEBUG_showinfo, "6rd found with prefix: %d", ipv6addrp->prefix2length);
 			// reduced SLA, mask value
 			if ((ipv6addrp->prefix2length + 32) > 48) {
@@ -1533,8 +1656,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* Proper solicited node link-local multicast address? */
-	if ( (typeinfo & IPV6_NEW_ADDR_SOLICITED_NODE) != 0 ) {
-		if ( (typeinfo & (IPV6_ADDR_LINKLOCAL & IPV6_ADDR_MULTICAST)) != 0 ) {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_SOLICITED_NODE) != 0) {
+		if ((ipv6addrp->typeinfo & (IPV6_ADDR_LINKLOCAL & IPV6_ADDR_MULTICAST)) != 0) {
 			/* address is ok */
 		} else {
 			if ( machinereadable != 0 ) {
@@ -1547,7 +1670,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 	
 	/* Compat or mapped */
-	if ( (typeinfo & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)) != 0 ) {
+	if ((ipv6addrp->typeinfo & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)) != 0) {
 		r = libipv6addr_get_included_ipv4addr(ipv6addrp, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 
 		if (r == 0) {
@@ -1561,7 +1684,9 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* Interface identifier included */
-	if ( ( ((typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) || ((typeinfo & (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) == (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) ) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID)) == 0) ) {
+	if ((((ipv6addrp->typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0)
+	    || ((ipv6addrp->typeinfo & (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) == (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)))
+	  && ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID)) == 0) ) {
 		if ( machinereadable != 0 ) {
 			snprintf(tempstring, sizeof(tempstring), "%04x:%04x:%04x:%04x", (unsigned int) ipv6addr_getword(ipv6addrp, 4), (unsigned int) ipv6addr_getword(ipv6addrp, 5), (unsigned int) ipv6addr_getword(ipv6addrp, 6), (unsigned int) ipv6addr_getword(ipv6addrp, 7));
 			printout("IID", tempstring, formatoptions);
@@ -1569,17 +1694,17 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 			fprintf(stdout, "Interface identifier: %04x:%04x:%04x:%04x\n", (unsigned int) ipv6addr_getword(ipv6addrp, 4), (unsigned int) ipv6addr_getword(ipv6addrp, 5), (unsigned int) ipv6addr_getword(ipv6addrp, 6), (unsigned int) ipv6addr_getword(ipv6addrp, 7));
 		};
 
-		if ((typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
+		if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
 			if ( machinereadable != 0 ) {
 			} else {
 				fprintf(stdout, "Interface identifier is an anonymized one\n");
 			};
 		};
 
-		if ((typeinfo & IPV6_NEW_ADDR_IID_EUI48) == IPV6_NEW_ADDR_IID_EUI48) {
+		if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_IID_EUI48) == IPV6_NEW_ADDR_IID_EUI48) {
 			/* EUI-48 */
-			if ((typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
-				payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, typeinfo) ^ 0x020000;
+			if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
+				payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, ipv6addrp->typeinfo) ^ 0x020000;
 
 				if ((payload & 0x1000000) != 0) {
 					libieee_unmap_oui_macaddr(&macaddr, payload);
@@ -1601,10 +1726,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 			};
 			print_eui48(&macaddr, formatoptions);
 		} else {
-			if ((typeinfo & IPV6_NEW_ADDR_IID_EUI64) == IPV6_NEW_ADDR_IID_EUI64) {
+			if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_IID_EUI64) == IPV6_NEW_ADDR_IID_EUI64) {
 				/* EUI-64 */
-				if ((typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
-					payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, typeinfo) ^ 0x020000;
+				if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_IID) == IPV6_ADDR_ANONYMIZED_IID) {
+					payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, ipv6addrp->typeinfo) ^ 0x020000;
 
 					if ((payload & 0x1000000) != 0) {
 						libieee_unmap_oui_eui64addr(&eui64addr, payload);
@@ -1630,19 +1755,19 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 				};
 				print_eui64(&eui64addr, formatoptions);
 			} else {
-				if ( (typeinfo & IPV6_NEW_ADDR_SOLICITED_NODE) != 0 ) {
+				if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_SOLICITED_NODE) != 0) {
 					if ( machinereadable != 0 ) {
 						snprintf(tempstring, sizeof(tempstring), "??:??:??:??:??:%02x:%02x:%02x", (unsigned int) ipv6addr_getoctet(ipv6addrp, 13), (unsigned int) ipv6addr_getoctet(ipv6addrp, 14), (unsigned int) ipv6addr_getoctet(ipv6addrp, 15));
 						printout("EUI64", tempstring, formatoptions);
 					} else {
 						fprintf(stdout, "Generated from the extension identifier of an EUI-48 (MAC): ...:%02x:%02x:%02x\n", (unsigned int) ipv6addr_getoctet(ipv6addrp, 13), (unsigned int) ipv6addr_getoctet(ipv6addrp, 14), (unsigned int) ipv6addr_getoctet(ipv6addrp, 15));
 					};
-				} else if ( (typeinfo & (IPV6_NEW_ADDR_IID_ISATAP | IPV6_NEW_ADDR_6TO4_MICROSOFT) ) != 0 )  {
-					if ((typeinfo & IPV6_ADDR_IID_32_63_HAS_IPV4) != 0) {
+				} else if ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_IID_ISATAP | IPV6_NEW_ADDR_6TO4_MICROSOFT) ) != 0)  {
+					if ((ipv6addrp->typeinfo & IPV6_ADDR_IID_32_63_HAS_IPV4) != 0) {
 						/* IPv4 address included */
 
-						if ((typeinfo & IPV6_ADDR_ANONYMIZED_IID) != 0) {
-							payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, typeinfo);
+						if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_IID) != 0) {
+							payload = ipv6addr_get_payload_anonymized_iid(ipv6addrp, ipv6addrp->typeinfo);
 							/* IPv4 */
 							ipv4addr_setoctet(&ipv4addr, 0, (payload >> 16) & 0xff);
 							ipv4addr_setoctet(&ipv4addr, 1, (payload >>  8) & 0xff);
@@ -1653,10 +1778,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 								ipv4addr_setoctet(&ipv4addr, (unsigned int) i, (unsigned int) ipv6addr_getoctet(ipv6addrp, (unsigned int) (i + 12)));
 							};
 						};
+						ipv4addr_settype(&ipv4addr, 1);
+						ipv4addr.flag_valid = 1;
 
-						ipv4addr.scope = ipv4addr_gettype(&ipv4addr);
-
-						if ( (typeinfo & IPV6_NEW_ADDR_IID_ISATAP) != 0 )  {
+						if ( (ipv6addrp->typeinfo & IPV6_NEW_ADDR_IID_ISATAP) != 0 )  {
 							print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "ISATAP");
 						} else {
 							print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "6to4-microsoft");
@@ -1675,7 +1800,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 							fprintf(stdout, "ISATAP extension ID: 0x%02x%02x%02x%02x%02x\n", ipv6addr_getoctet(ipv6addrp, 11), ipv6addr_getoctet(ipv6addrp, 12), ipv6addr_getoctet(ipv6addrp, 13), ipv6addr_getoctet(ipv6addrp, 14), ipv6addr_getoctet(ipv6addrp, 15));
 						};
 					};
-				} else if ( ( ( (typeinfo & IPV6_ADDR_LINKLOCAL) != 0) && (ipv6addr_getdword(ipv6addrp, 2) == 0 && ipv6addr_getword(ipv6addrp, 6) != 0)) )   {
+				} else if ((((ipv6addrp->typeinfo & IPV6_ADDR_LINKLOCAL) != 0) && (ipv6addr_getdword(ipv6addrp, 2) == 0 && ipv6addr_getword(ipv6addrp, 6) != 0)))   {
 					/* fe80:: must have 0000:0000:xxxx:yyyy where xxxx > 0 */
 					if ( machinereadable != 0 ) {
 					} else {
@@ -1685,7 +1810,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					for (i = 0; i <= 3; i++) {
 						ipv4addr_setoctet(&ipv4addr, (unsigned int) i, (unsigned int) ipv6addr_getoctet(ipv6addrp, (unsigned int) (i + 12)));
 					};
-					ipv4addr.scope = ipv4addr_gettype(&ipv4addr);
+					ipv4addr_settype(&ipv4addr, 1);
+					ipv4addr.flag_valid = 1;
 
 					if ( machinereadable != 0 ) {
 						// printout("IPV4_SOURCE=LINK-LOCAL-IID");
@@ -1694,17 +1820,17 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					print_ipv4addr(&ipv4addr, formatoptions | FORMATOPTION_printembedded, "LINK-LOCAL-IID");
 				} else {
 					if ( machinereadable != 0 ) {
-						if ((typeinfo & IPV6_NEW_ADDR_6TO4_MICROSOFT) != 0) {
+						if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_6TO4_MICROSOFT) != 0) {
 							printout("EUI64_SCOPE", "local-6to4-microsoft", formatoptions);
-						} else if ((typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
+						} else if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
 							printout("EUI64_SCOPE", "local-random", formatoptions);
 						} else {
 							printout("EUI64_SCOPE", "local", formatoptions);
 						};
 					} else {
-						if ((typeinfo & IPV6_NEW_ADDR_6TO4_MICROSOFT) != 0) {
+						if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_6TO4_MICROSOFT) != 0) {
 							fprintf(stdout, "Interface identifier contain only IPv4 address from 6to4 prefix, usually seen on Microsoft OS\n");
-						} else if ((typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
+						} else if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
 							fprintf(stdout, "Interface identifier is probably generated by privacy extension\n");
 						} else {
 							fprintf(stdout, "Interface identifier is probably manual set\n");
@@ -1715,7 +1841,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		};
 	};
 
-	if ( (typeinfo & IPV6_NEW_ADDR_ORCHID) != 0) {
+	if ((ipv6addrp->typeinfo & IPV6_NEW_ADDR_ORCHID) != 0) {
 		/* 'extract' hash */
 		ipv6addr_setword(ipv6addrp, 0, 0x0000);
 		ipv6addr_setword(ipv6addrp, 1, ipv6addr_getword(ipv6addrp, 1) & 0x000F);
@@ -1724,7 +1850,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 		if ( machinereadable != 0 ) {
 		} else {
-			if ((typeinfo & IPV6_ADDR_ANONYMIZED_IID) != 0) {
+			if ((ipv6addrp->typeinfo & IPV6_ADDR_ANONYMIZED_IID) != 0) {
 				snprintf(tempstring, sizeof(tempstring), "n/a (previosly anonymized)");
 			} else {
 				snprintf(tempstring, sizeof(tempstring), "%s", ipv6addrstring+7);
@@ -1736,7 +1862,7 @@ END:
 
 	i = libipv6calc_db_wrapper_registry_num_by_ipv6addr(ipv6addrp);
 	if ((i != IPV6_ADDR_REGISTRY_RESERVED) && (i != IPV6_ADDR_REGISTRY_6BONE)) {
-		if ( ((typeinfo & IPV6_NEW_ADDR_AGU) != 0) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0) ) {
+		if (((ipv6addrp->typeinfo & IPV6_NEW_ADDR_AGU) != 0) && ((ipv6addrp->typeinfo & (IPV6_NEW_ADDR_TEREDO | IPV6_NEW_ADDR_ORCHID | IPV6_ADDR_ANONYMIZED_PREFIX)) == 0)) {
 #ifdef SUPPORT_IP2LOCATION
 			/* IP2Location information */
 			print_ip2location(ipv6addrstring, formatoptions, "", 6);
