@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_scenarios.sh
-# Version    : $Id: 4ab6783bc4317ab29d77d78baa1224c371694352 $
-# Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: bc24262d4c239d03597fa161bcc86fab08180ee1 $
+# Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de>
 # License    : GPLv2
 #
 # Test patterns for ipv6calc (functions only)
@@ -193,8 +193,8 @@ fe80::5e01:2345:6789				iid-isatap
 3ffe:1a05:510:a909:a949:5214:48ca:d81d		iid-isatap
 3ffe:1a05:510:a909:a949:5214:48ca:d81d		^iid-random
 2001:4860:4801:2:3800:6006:1300:b075		^iid-random
-3ffe:ffff::a4ff:fe01:2345			iid-local
-3ffe:ffff::a4ff:fe01:2345			iid-eui48
+3ffe:ffff::a4ff:fe01:2345			iid-local,iid-eui48
+3ffe:ffff::0200:a4ff:fe01:2345			iid-global,iid-eui48
 fe80:0000:0000:0000:0200:5efe:192.0.2.143	^anonymized-iid
 fe80:0000:0000:0000:0000:5e01:2345:6789		^anonymized-iid
 fe80:0000:0000:0000:0000:5eff:fe01:2345		^anonymized-iid
@@ -239,6 +239,15 @@ a909:16fa:9092:23ff:a909:4941::7		anonymized-prefix
 2001:db8::2					^ipv6.addr=lt=2001:db8::1
 2.2.3.4						^ipv4.addr=gt=2.2.3.5
 2.2.3.4						^ipv4.addr=lt=2.2.3.3
+2610:00d0::1					lisp
+2001:67c:198::1					lisp-proxyegresstunnelrouter-anycast,anycast,^unicast
+2001:67c:28::1					lisp-mapresolver-anycast,anycast,^unicast
+153.16.0.1					lisp,unicast
+193.105.183.1					lisp,lisp-proxyegresstunnelrouter-anycast,anycast,^unicast
+91.220.201.1					lisp,lisp-mapresolver-anycast,anycast,^unicast
+192.88.99.1					anycast,^unicast,6to4relay
+2001:0db8:0000:0000:81c0:0f3f:c807:1455 	iid-random,iid-local
+2001:0db8:0000:0000::1			 	iid-local,^iid-random
 END
 }
 
@@ -343,6 +352,19 @@ testscenarios_anonymization_options() {
 # EUI-48: global (OUI-36)
 --anonymize-preset zc		00:1b:c5:03:df:ff=00:1b:c5:03:d0:00
 --anonymize-preset zc --mask-mac 16 --mask-autoadjust no	00:1b:c5:03:df:ff=00:1b:00:00:00:00
+# LISP Anycast
+--mask-ipv6 16				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
+--mask-ipv6 24				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
+--mask-ipv6 32				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
+--mask-ipv6 40				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
+--mask-ipv6 48				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:a909:a949:4291:c02d:5d13
+--mask-ipv6 56				2001:67c:198:f123:0123:4567:89ab:cdef=2001:67c:198:f109:a929:4291:c02d:5d15
+--mask-ipv6 16				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:a909:a949:4291:c02d:5d13
+--mask-ipv6 24				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:a909:a949:4291:c02d:5d13
+--mask-ipv6 32				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:a909:a949:4291:c02d:5d13
+--mask-ipv6 40				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:a909:a949:4291:c02d:5d13
+--mask-ipv6 48				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:a909:a949:4291:c02d:5d13
+--mask-ipv6 56				2001:67c:28:f123:0123:4567:89ab:cdef=2001:67c:28:f109:a929:4291:c02d:5d15
 END
 }
 
@@ -356,6 +378,8 @@ testscenarios_anonymization_options_kp() {
 --anonymize-preset kp			3ffe:831f:ce49:7601:8000:efff:af4a:86bf=3ffe:831f:ce49:7601:8000:ffff:a0b:f33a
 --anonymize-preset kp			64:ff9b::0202:0304=64:ff9b::fd86:c8f
 --anonymize-preset kp			2001:0db8:0000:0000:81c0:0f3f:c807:1455=2001:db8::a909:4941:0:7
+# do not anonymize LISP anycast prefix
+--anonymize-preset kp			2001:67c:198::1=2001:67c:198::a909:4291:c02d:5d1d
 END
 }
 
@@ -416,6 +440,9 @@ a909:16fa:9092:23ff:a909:4941::7	IPV6_REGISTRY=RIPENCC
 2001:b4f:0:804::/62			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 30
 2001:b4f:8000:402::/63			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 31
 2001:b4f:c000:201::/64			IPV4[192.0.2.1]=192.0.2.1|--6rd_prefixlength 32
+# LISP
+153.16.13.192				IPV4_REGISTRY=ARIN(LISP#aaronm-xtr)
+2610:00d0:1100::			IPV6_REGISTRY=ARIN(LISP#asp-xtr)
 END
 }
 
