@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganon.c
- * Version    : $Id: 61b55bf8c7dbe2504b86f4e1d6f7dec071063680 $
- * Copyright  : 2007-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ad0cb3ded29cf5c7ed33ffe4a0634cf8fa3ce5cc $
+ * Copyright  : 2007-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile anonymization
@@ -128,9 +128,9 @@ int main(int argc,char *argv[]) {
 
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Parsing option: 0x%08x", i);
+		DEBUGPRINT_WA(DEBUG_ipv6loganon_general, "Parsing option: 0x%08x (%d: %s)", i, optind, argv[optind - 1]);
 
-		if ((i == '?') && (optopt != 0)) {
+		if ((i == '?') && (strcmp(argv[optind - 1], "-?") != 0)) {
 			exit(EXIT_FAILURE);
 		};
 
