@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6loganonoptions.h
- * Version    : $Id: ipv6loganonoptions.h,v 1.13 2013/10/28 20:10:17 ds6peter Exp $
+ * Version    : $Id: e0c9c7bb718671f28748aed60b1449e5b5490d72 $
  * Copyright  : 2007-2013 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -20,12 +20,11 @@
 /* Options */
 
 /* define short options */
-static char *ipv6loganon_shortopts = "vh?Vnc:w:a:f";
+static char *ipv6loganon_shortopts = "vh?nc:w:a:f";
 
 /* define long options */
 static struct option ipv6loganon_longopts[] = {
 	{"version", 0, NULL, (int) 'v' },
-	{"verbose", 0, NULL, (int) 'V' },
 
 	/* help options */
 	{"help"           , 0, NULL, (int) 'h'},
