@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6logconv.c
- * Version    : $Id: 59d88133eac2042cf582469427384e5f60b57856 $
- * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 17c372190c0d3d2286f6b63e3dcda4fd1a2b1764 $
+ * Copyright  : 2002-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile conversions
@@ -121,9 +121,9 @@ int main(int argc,char *argv[]) {
 
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		DEBUGPRINT_WA(DEBUG_ipv6logconv_general, "Parsing option: 0x%08x", i);
+		DEBUGPRINT_WA(DEBUG_ipv6logconv_general, "Parsing option: 0x%08x (%d: %s)", i, optind, argv[optind - 1]);
 
-		if ((i == '?') && (optopt != 0)) {
+		if ((i == '?') && (strcmp(argv[optind - 1], "-?") != 0)) {
 			exit(EXIT_FAILURE);
 		};
 
@@ -218,7 +218,7 @@ int main(int argc,char *argv[]) {
 	};
 
 	/* print help handling */
-	if (command == CMD_printhelp) {
+	if (command & CMD_printhelp) {
 		ipv6logconv_printhelp();
 		exit(EXIT_FAILURE);
         } else if (command == CMD_printexamples) {
@@ -502,7 +502,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 				snprintf(resultstring, resultstring_length, "ipv6-addr.addrtype.ipv6calc");
 
 				/* check for registry */
-				typeinfo = ipv6addr_gettype(&ipv6addr);
+				typeinfo = ipv6addr_gettype(&ipv6addr, NULL);
 
 				/* scope of IPv6 address */
 				/* init retval */
@@ -578,7 +578,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 						exit(EXIT_FAILURE);
 					};
 
-					ipv4addr.scope = ipv4addr_gettype(&ipv4addr);
+					ipv4addr_settype(&ipv4addr, 1); /* Set typeinfo */
 
 					/* IPv4 registry */
 					registry = libipv4addr_registry_num_by_addr(&ipv4addr);
@@ -607,7 +607,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 				};
 		       	};
 
-			typeinfo = ipv6addr_gettype(&ipv6addr);
+			typeinfo = ipv6addr_gettype(&ipv6addr, NULL);
 
 			/* check whether address has a OUI ID */
 			if ( (( typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_NEW_ADDR_6BONE | IPV6_NEW_ADDR_6TO4 | IPV6_ADDR_ULUA)) == 0) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO)) == 0) )  {
@@ -667,7 +667,7 @@ static int converttoken(char *resultstring, const size_t resultstring_length, co
 				};
 		       	};
 
-			typeinfo = ipv6addr_gettype(&ipv6addr);
+			typeinfo = ipv6addr_gettype(&ipv6addr, NULL);
 
 		       	if ( (typeinfo & IPV6_ADDR_LINKLOCAL) != 0 ) {
 				snprintf(resultstring, resultstring_length, "link-local.ipv6addrtype.ipv6calc");
