@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstats.c
- * Version    : $Id: 52e96d716cbf2b1a52b4c2a5fb0fad6146318c9c $
- * Copyright  : 2003-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 7cc0003f22901643231e0fdb7863f4e62c285436 $
+ * Copyright  : 2003-2017 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Dedicated program for logfile statistics
@@ -165,9 +165,9 @@ int main(int argc,char *argv[]) {
 
 	/* Fetch the command-line arguments. */
 	while ((i = getopt_long(argc, argv, shortopts, longopts, &lop)) != EOF) {
-		DEBUGPRINT_WA(DEBUG_ipv6logstats_general, "Parsing option: 0x%08x", i);
+		DEBUGPRINT_WA(DEBUG_ipv6logstats_general, "Parsing option: 0x%08x (%d: %s)", i, optind, argv[optind - 1]);
 
-		if ((i == '?') && (optopt != 0)) {
+		if ((i == '?') && (strcmp(argv[optind - 1], "-?") != 0)) {
 			exit(EXIT_FAILURE);
 		};
 
@@ -293,7 +293,7 @@ int main(int argc,char *argv[]) {
 		exit(EXIT_SUCCESS);
 	};
 
-	if (command == CMD_printhelp) {
+	if (command & CMD_printhelp) {
 		ipv6logstats_printhelp();
 		exit(EXIT_FAILURE);
 	};
@@ -515,7 +515,7 @@ static void lineparser(void) {
 		/* catch compat/mapped */
 		switch (inputtype) {
 			case FORMAT_ipv6addr:
-				if ((ipv6addr.scope & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)) != 0) {
+				if ((ipv6addr.typeinfo & (IPV6_ADDR_COMPATv4 | IPV6_ADDR_MAPPED)) != 0) {
 					/* extract IPv4 address */
 					r = libipv6addr_get_included_ipv4addr(&ipv6addr, &ipv4addr, IPV6_ADDR_SELECT_IPV4_DEFAULT);
 					if (r != 0) {
@@ -541,7 +541,7 @@ static void lineparser(void) {
 				/* is IPv6 address */
 				stat_inc(STATS_IPV6);
 
-				if ((ipv6addr.scope & IPV6_ADDR_HAS_PUBLIC_IPV4) != 0) {
+				if ((ipv6addr.typeinfo & IPV6_ADDR_HAS_PUBLIC_IPV4) != 0) {
 					/* has public IPv4 address included */
 
 					// get IPv4 address (in case of Teredo the client IP)
@@ -564,13 +564,13 @@ static void lineparser(void) {
 
 					registry = libipv4addr_registry_num_by_addr(&ipv4addr);
 
-					if ((ipv6addr.scope & IPV6_NEW_ADDR_6TO4) != 0) {
+					if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_6TO4) != 0) {
 						stat_registry_base = STATS_IPV6_6TO4_BASE;
 
-					} else if ((ipv6addr.scope & IPV6_NEW_ADDR_TEREDO) != 0) {
+					} else if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_TEREDO) != 0) {
 						stat_registry_base = STATS_IPV6_TEREDO_BASE;
 
-					} else if ((ipv6addr.scope & IPV6_NEW_ADDR_NAT64) != 0) {
+					} else if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_NAT64) != 0) {
 						stat_registry_base = STATS_IPV6_NAT64_BASE;
 					};
 
@@ -660,14 +660,14 @@ static void lineparser(void) {
 							break;
 					};
 
-					if ((ipv6addr.scope & IPV6_NEW_ADDR_IID) == IPV6_NEW_ADDR_IID) {
-						if ((ipv6addr.scope & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
+					if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID) == IPV6_NEW_ADDR_IID) {
+						if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID_RANDOM) != 0) {
 							stat_inc(STATS_IPV6_IID_RANDOM);
-						} else if ((ipv6addr.scope & IPV6_NEW_ADDR_IID_ISATAP) != 0) {
+						} else if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID_ISATAP) != 0) {
 							stat_inc(STATS_IPV6_IID_ISATAP);
-						} else if ((ipv6addr.scope & IPV6_NEW_ADDR_IID_LOCAL) != 0) {
+						} else if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID_LOCAL) != 0) {
 							stat_inc(STATS_IPV6_IID_MANUAL);
-						} else if ((ipv6addr.scope & IPV6_NEW_ADDR_IID_GLOBAL) != 0) {
+						} else if ((ipv6addr.typeinfo & IPV6_NEW_ADDR_IID_GLOBAL) != 0) {
 							stat_inc(STATS_IPV6_IID_GLOBAL);
 						} else {
 							stat_inc(STATS_IPV6_IID_UNKNOWN);
