@@ -1,7 +1,7 @@
 /*
  * Project    : ipv6calc/ipv6logstats
  * File       : ipv6logstatshelp.c
- * Version    : $Id: 65c0f3ea06527c9f2df75c2397370f5253d8e736 $
+ * Version    : $Id: 628937beacecdad066d2aae53e9fbf83e65e0fbc $
  * Copyright  : 2003-2014 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
@@ -41,11 +41,11 @@ void printversion(void) {
 void printversion_help(void) {
 	fprintf(stderr, "\n");
 
-	fprintf(stderr, "Explanation of available(+)/possible(-) feature tokens\n");
+	fprintf(stderr, "Explanation of available(x)/possible(o) feature tokens\n");
 
-	fprintf(stderr, "%-22s%c %s\n", "STAT_REG", (feature_reg == 1)? '+' : '-', "Statistics by Registry");
-	fprintf(stderr, "%-22s%c %s\n", "STAT_CC", (feature_cc == 1) ? '+' : '-', "Statistics by CountryCode");
-	fprintf(stderr, "%-22s%c %s\n", "STAT_AS", (feature_as == 1) ? '+' : '-', "Statistics by Autonomous System Number");
+	fprintf(stderr, "%-22s%c %s\n", "STAT_REG", (feature_reg == 1)? 'x' : 'o', "Statistics by Registry");
+	fprintf(stderr, "%-22s%c %s\n", "STAT_CC", (feature_cc == 1) ? 'x' : 'o', "Statistics by CountryCode");
+	fprintf(stderr, "%-22s%c %s\n", "STAT_AS", (feature_as == 1) ? 'x' : 'o', "Statistics by Autonomous System Number");
 
 	fprintf(stderr, "\n");
 };
