@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calchelp.c
- * Version    : $Id: f6d90fc38c790d9ee526e7725855b71250897e7c $
- * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 8a1f0237e76ce77f80f9b198e3f9f2eae6d584f5 $
+ * Copyright  : 2002-2017 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Help library
@@ -353,6 +353,9 @@ void printhelp_common(const uint32_t help_features) {
 		fprintf(stderr, "  [--disable-dbip                  ] : db-ip.com support disabled\n");
 		fprintf(stderr, "  [--db-dbip-disable               ] : db-ip.com support disabled\n");
 		fprintf(stderr, "  [--db-dbip-dir        <directory>] : db-ip.com database directory (default: %s)\n", dbip_db_dir);
+		fprintf(stderr, "  [--db-dbip-only-type <TYPE>]       : db-ip.com database only selected type (1-%d)\n", DBIP_DB_MAX);
+		fprintf(stderr, "  [--db-dbip-comm-to-free-switch-min-delta-months <MONTHS>]:\n");
+		fprintf(stderr, "     switch from COMM to FREE databases if possible and delta more than %d months (0=disabled)\n", dbip_db_comm_to_free_switch_min_delta_months);
 #endif
 	};
 
@@ -911,10 +914,10 @@ void ipv6calc_print_features_verbose(const int level_verbose) {
 #ifdef IP2LOCATION_INCLUDE_VERSION
 	fprintf(stderr, "IP2Location support enabled, compiled with include file version: %s\n", IP2LOCATION_INCLUDE_VERSION);
 #endif
-#if SUPPORT_IP2LOCATION_API_VERSION_STRING
+#ifdef SUPPORT_IP2LOCATION_API_VERSION_STRING
 	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s, dynamically linked with version: %s\n", xmakestr(API_VERSION), libipv6calc_db_wrapper_IP2Location_lib_version());
-#else
-	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s (linked version not supported)\n", xmakestr(API_VERSION));
+#else  // SUPPORT_IP2LOCATION_API_VERSION_STRING
+	fprintf(stderr, "IP2Location support enabled, compiled with API version: %s (retrieving linked version not supported - older version)\n", xmakestr(API_VERSION));
 #endif // SUPPORT_IP2LOCATION_API_VERSION_STRING
 #ifndef SUPPORT_IP2LOCATION_DYN
 #else
