@@ -1,8 +1,9 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calctypes.h
- * Version    : $Id: ipv6calctypes.h,v 1.53 2015/08/23 09:53:27 ds6peter Exp $
- * Copyright  : 2002-2015 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: 517ca7a4cbd8b456ff0e15ee831863f9ea4bb4ca $
+ * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de>
+ * License    : GPLv2
  *
  * Information:
  *  Header file for ipv6calctypes.c
@@ -270,6 +271,7 @@ typedef struct {
 #define ACTION_NUM_6rd_extract_ipv4	7
 #define ACTION_NUM_ipv4_to_nat64	8
 #define ACTION_NUM_filter		15
+#define ACTION_NUM_test			16
 #define ACTION_NUM_undefined		31
 
 #define ACTION_auto			(uint32_t) 0x0
@@ -282,6 +284,7 @@ typedef struct {
 #define ACTION_6rd_extract_ipv4		(uint32_t) (1 << ACTION_NUM_6rd_extract_ipv4)
 #define ACTION_ipv4_to_nat64		(uint32_t) (1 << ACTION_NUM_ipv4_to_nat64)
 #define ACTION_filter			(uint32_t) (1 << ACTION_NUM_filter)
+#define ACTION_test			(uint32_t) (1 << ACTION_NUM_test)
 #define ACTION_undefined		(uint32_t) (1 << ACTION_NUM_undefined)
 
 #define ANON_METHOD_ANONYMIZE		1
@@ -306,10 +309,12 @@ typedef struct {
 	{ ACTION_6rd_local_prefix     , "6rd_local_prefix", "Calculate the 6rd prefix from given IPv6 prefix (& relay prefix) and IPv4", "" },
 	{ ACTION_6rd_extract_ipv4     , "6rd_extract_ipv4", "Extract from 6rd address the include IPv4 address", "" },
 	{ ACTION_filter	              , "filter"          , "Filter addresses related to filter options", "" },
+	{ ACTION_test                 , "test"            , "Test address against given prefix or address", "" },
 };
 
 /* Possible action option map (required) */
 /*@unused@*/ static const uint32_t ipv6calc_actionoptionmap[][3]  = {
+	// action, command, 0=required, 1=optional
 	{ ACTION_auto			, 0 , 0},
 	{ ACTION_mac_to_eui64		, 0 , 0},
 	{ ACTION_ipv4_to_6to4addr	, 0 , 0},
@@ -320,6 +325,11 @@ typedef struct {
 	{ ACTION_6rd_local_prefix	, CMD_6rd_prefix, 0},
 	{ ACTION_6rd_local_prefix	, CMD_6rd_relay_prefix, 1 },
 	{ ACTION_6rd_extract_ipv4	, CMD_6rd_prefixlength, 0},
+	{ ACTION_test			, CMD_test_prefix, 1},
+	{ ACTION_test			, CMD_test_gt, 1},
+	{ ACTION_test			, CMD_test_ge, 1},
+	{ ACTION_test			, CMD_test_lt, 1},
+	{ ACTION_test			, CMD_test_le, 1},
 };
 
 /* anonymization set */
@@ -386,6 +396,15 @@ typedef struct {
 } s_ipv6calc_filter_typeinfo;
 
 
+#define IPV6CALC_TEST_PREFIX	1
+#define IPV6CALC_TEST_GT	2
+#define IPV6CALC_TEST_GE	3
+#define IPV6CALC_TEST_LT	4
+#define IPV6CALC_TEST_LE	5
+
+#define IPV6CALC_TEST_LIST_MIN	IPV6CALC_TEST_PREFIX
+#define IPV6CALC_TEST_LIST_MAX	IPV6CALC_TEST_LE
+
 #endif // _ipv6calctypes_h_
 
 
