@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv4addr.h
- * Version    : $Id: c4364cfbb6a73715629def9afa3f82c969cf86bb $
- * Copyright  : 2002-2016 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: a410901fcd25784ed8615b3b3116ec0e3139f53a $
+ * Copyright  : 2002-2017 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -19,12 +19,14 @@
 
 /* IPv4 address structure */
 typedef struct {
-	struct in_addr in_addr;		/* in_addr structure */
-	uint8_t prefixlength;		/* prefix length (0-32) 8 bit */
-	int flag_prefixuse;		/* =1 prefix length in use (CIDR notation) */
-	uint32_t scope;			/* address typeinfo/scope */
-	int flag_valid;			/* address structure filled */
-	uint8_t test_mode;		/* test mode */
+	struct   in_addr in_addr;	/* in_addr structure */
+	uint8_t  prefixlength;		/* prefix length (0-32) 8 bit */
+	int      flag_prefixuse;	/* =1: prefix length in use (CIDR notation) */
+	uint32_t typeinfo;		/* address typeinfo/scope */
+	uint32_t typeinfo2;		/* address typeinfo/scope #2 */
+	int8_t   flag_typeinfo;		/* =1: valid typeinfo */
+	int8_t   flag_valid;		/* address structure filled */
+	uint8_t  test_mode;		/* test mode */
 } ipv6calc_ipv4addr;
 
 /* IPv4 Address filter structure */
@@ -54,10 +56,10 @@ typedef struct {
 
 #define IPV4_ADDR_ANY				(uint32_t) 0x00000000U
 
-#define IPV4_ADDR_UNICAST			(uint32_t) 0x00000001U	
-#define IPV4_ADDR_MULTICAST			(uint32_t) 0x00000002U	
-#define IPV4_ADDR_ANYCAST			(uint32_t) 0x00000004U	
-#define IPV4_ADDR_BROADCAST			(uint32_t) 0x00000008U	
+#define IPV4_ADDR_UNICAST			(uint32_t) 0x00000001U
+#define IPV4_ADDR_MULTICAST			(uint32_t) 0x00000002U
+#define IPV4_ADDR_ANYCAST			(uint32_t) 0x00000004U
+#define IPV4_ADDR_BROADCAST			(uint32_t) 0x00000008U
 #define IPV4_ADDR_LOOPBACK			(uint32_t) 0x00000010U
 #define IPV4_ADDR_UNSPECIFIED			(uint32_t) 0x00000020U
 #define IPV4_ADDR_ANONYMIZED			(uint32_t) 0x00000100U
@@ -70,6 +72,10 @@ typedef struct {
 
 #define IPV4_ADDR_6TO4RELAY			(uint32_t) 0x01000000U
 
+#define IPV4_ADDR_LISP				(uint32_t) 0x00010000U	/* IPv6 LISP (RFC6830) */
+#define IPV4_ADDR_LISP_PETR			(uint32_t) 0x00020000U	/* IPv6 LISP Proxy Egress Tunnel Routers (PETRY) Anycast */
+#define IPV4_ADDR_LISP_MAP_RESOLVER		(uint32_t) 0x00040000U	/* IPv6 LISP Map Resolver Anycast */
+
 
 /* text representation */
 /*@unused@*/ static const s_type ipv6calc_ipv4addrtypestrings[] = {
@@ -86,7 +92,10 @@ typedef struct {
 	{ IPV4_ADDR_SITELOCAL		, "site-local" },
 	{ IPV4_ADDR_ANONYMIZED		, "anonymized" },
 	{ IPV4_ADDR_GLOBAL		, "global" },
-	{ IPV4_ADDR_6TO4RELAY		, "6to4relay" }
+	{ IPV4_ADDR_6TO4RELAY		, "6to4relay" },
+	{ IPV4_ADDR_LISP	 	, "lisp" },
+	{ IPV4_ADDR_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
+	{ IPV4_ADDR_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
 };
 
 
@@ -101,7 +110,7 @@ typedef struct {
 #define IPV4_ADDR_REGISTRY_UNKNOWN	REGISTRY_UNKNOWN
 
 /* IPv4 address anonymization
- *  Global IPv4 addresses are anoymized by storing country code and AS number
+ *  Global IPv4 addresses are anonymized by storing country code and AS number
  *   and using prefix of experimental range (240-255.x.y.z)
  *
  *  3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
@@ -111,7 +120,7 @@ typedef struct {
  *  Prefix                
  *    0xF
  *
- * Pariy Bit (odd parity)
+ * Parity Bit (odd parity)
  *         |P|
  *
  * Mapping of Country Code
@@ -138,6 +147,9 @@ typedef struct {
  *                                  1 0 0 = LACNIC
  *                                  1 0 1 = AFRINIC
  *                                  1 1 0 = ARIN
+ *
+ * Mapping of LISP
+ *                                1|r r r|1|1|0 0 0 0 0 0 0 0 0 0 0|
  */
 
 #define ANON_METHOD_KEEPTYPEASNCC_IPV4_REQ_DB   (IPV6CALC_DB_IPV4_TO_CC | IPV6CALC_DB_IPV4_TO_AS)
@@ -161,6 +173,7 @@ extern void ipv4addr_copy(ipv6calc_ipv4addr *ipv4addrp_dst, const ipv6calc_ipv4a
 extern int ipv4addr_compare(const ipv6calc_ipv4addr *ipv4addrp1, const ipv6calc_ipv4addr *ipv4addrp2, const uint16_t compare_flags);
 
 extern uint32_t ipv4addr_gettype(const ipv6calc_ipv4addr *ipv4addrp);
+extern void ipv4addr_settype(ipv6calc_ipv4addr *ipv4addrp, int flag_reset);
 
 extern int addr_to_ipv4addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv4addr *ipv4addrp);
 extern int addrhex_to_ipv4addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv4addr *ipv4addrp, const int flag_reverse);
@@ -178,7 +191,7 @@ extern uint16_t ipv4addr_anonymized_get_cc_index(const ipv6calc_ipv4addr *ipv4ad
 
 extern int ipv4addr_filter(const ipv6calc_ipv4addr *ipv4addrp, const s_ipv6calc_filter_ipv4addr *filter);
 extern int ipv4addr_filter_parse(s_ipv6calc_filter_ipv4addr *filter, const char *token);
-extern int ipv4addr_filter_check(s_ipv6calc_filter_ipv4addr *filter);
+extern int ipv4addr_filter_check(const s_ipv6calc_filter_ipv4addr *filter);
 extern void ipv4addr_filter_clear(s_ipv6calc_filter_ipv4addr *filter);
 
 extern uint16_t libipv4addr_cc_index_by_addr(const ipv6calc_ipv4addr *ipv4addrp, unsigned int *data_source_ptr);
