@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : libipv6addr.h
- * Version    : $Id: 55c6029973ac38bfd19da34343cba5bbd4fa84bb $
- * Copyright  : 2001-2016 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: 3f20ce854f6221680fd5023873bf0fdc48d50ec8 $
+ * Copyright  : 2001-2017 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  * License    : GNU GPL v2
  *
  * Information:
@@ -47,11 +47,13 @@
  *   		0 : no nibble of prefix is anonymized
  *   		f : Prefix anonymization with method=kp
  *
- * Prefix anonymization in case of method=kp: p=0x0f
+ * Prefix anonymization in case of method=kp: p=0x0f, but skipped for
+ *  - LISP anycast
  * a909:ccca:aaaa:aaaC  (C = 4-bit checksum)
  *                      ccc      -> 10-bit Country Code mapping [A-Z]*[A-Z0-9] (936)
+ *                                   0x3FD = LISP
  *                                   0x3FE = unknown country
- *                                   0x3FD & ASN=0 = 6bone
+ *                                   0x3FF - 16 + REGISTRY_6BONE && ASN=0 = 6bone
  *                                   0x000-0x3A7: c1= c / 36, c2 = c % 36
  *                      aaaaaaaa -> 32-bit ASN
  */
@@ -164,19 +166,20 @@
 
 /* IPv6 address storage structure */
 typedef struct {
-	struct in6_addr in6_addr;	/* in6_addr structure */
-	uint8_t prefixlength;		/* prefix length (0-128) 8 bit */
-	int flag_prefixuse;		/* =1 prefix length in use */
-	uint32_t scope;			/* address typeinfo/scope */
+	struct   in6_addr in6_addr;	/* in6_addr structure */
+	uint8_t  prefixlength;		/* prefix length (0-128) 8 bit */
+	int      flag_prefixuse;	/* =1: prefix length in use */
+	uint32_t typeinfo;		/* address typeinfo/scope */
 	uint32_t typeinfo2;		/* address typeinfo2 */
-	uint8_t bit_start;		/* start of bit */
-	uint8_t bit_end;		/* end of bit */
-	int flag_startend_use;		/* =1 start or end of bit in use */
-	int flag_valid;			/* address structure filled */
-	char scopeid[IPV6CALC_SCOPEID_STRING_MAX];	/* scope ID value */
-	int flag_scopeid;		/* =1: scope ID value set */
-	uint8_t prefix2length;		/* prefix 2 length (0-128) 8 bit (usage depends on typeinfo/typeinfo2)*/
-	uint8_t test_mode;		/* address test mode */
+	int8_t   flag_typeinfo;		/* =1: typeinfo valid */
+	uint8_t  bit_start;		/* start of bit */
+	uint8_t  bit_end;		/* end of bit */
+	int8_t   flag_startend_use;	/* =1: start or end of bit in use */
+	int8_t   flag_valid;		/* address structure filled */
+	char     scopeid[IPV6CALC_SCOPEID_STRING_MAX];	/* scope ID value */
+	int8_t   flag_scopeid;		/* =1: scope ID value (above) set */
+	uint8_t  prefix2length;		/* prefix 2 length (0-128) 8 bit (usage depends on typeinfo/typeinfo2)*/
+	uint8_t  test_mode;		/* address test mode */
 } ipv6calc_ipv6addr;
 
 /* IPv6 Address filter structure */
@@ -192,6 +195,7 @@ typedef struct {
 typedef struct {
 	int active;
 	s_ipv6calc_filter_typeinfo    filter_typeinfo;
+	s_ipv6calc_filter_typeinfo    filter_typeinfo2;
 	s_ipv6calc_filter_db_cc       filter_db_cc;        // Country Code filter
 	s_ipv6calc_filter_db_asn      filter_db_asn;       // Autonomous System Number filter
 	s_ipv6calc_filter_db_registry filter_db_registry;  // Registry filter
@@ -303,6 +307,9 @@ typedef struct {
 
 // typeinfo2
 #define IPV6_ADDR_TYPE2_6RD			(uint32_t) 0x00000001U	/* IPv6 Rapid Deployment address (RFC5569), not autodetectable (triggered by --6rd_prefixlength) */
+#define IPV6_ADDR_TYPE2_LISP			(uint32_t) 0x00010000U	/* IPv6 LISP (RFC6830) */
+#define IPV6_ADDR_TYPE2_LISP_PETR		(uint32_t) 0x00020000U	/* IPv6 LISP Proxy Egress Tunnel Routers (PETRY) Anycast */
+#define IPV6_ADDR_TYPE2_LISP_MAP_RESOLVER	(uint32_t) 0x00040000U	/* IPv6 LISP Map Resolver Anycast */
 
 // IPv4 address extractor selector
 #define IPV6_ADDR_SELECT_IPV4_DEFAULT		0
@@ -349,6 +356,9 @@ typedef struct {
 /* text representations */
 /*@unused@*/ static const s_type ipv6calc_ipv6addr_type2_strings[] = {
 	{ IPV6_ADDR_TYPE2_6RD		, "6rd" },
+	{ IPV6_ADDR_TYPE2_LISP	 		, "lisp" },
+	{ IPV6_ADDR_TYPE2_LISP_PETR		, "lisp-proxyegresstunnelrouter-anycast" },
+	{ IPV6_ADDR_TYPE2_LISP_MAP_RESOLVER	, "lisp-mapresolver-anycast" },
 };
 
 /* Registries */
@@ -393,8 +403,8 @@ extern void ipv6addr_copy(ipv6calc_ipv6addr *ipv6addrp_dst, const ipv6calc_ipv6a
 
 extern int ipv6addr_compare(const ipv6calc_ipv6addr *ipv6addrp1, const ipv6calc_ipv6addr *ipv6addrp2, const uint16_t compare_flags);
 
-extern uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp);
-extern uint32_t ipv6addr_gettype2(const ipv6calc_ipv6addr *ipv6addrp);
+extern uint32_t ipv6addr_gettype(const ipv6calc_ipv6addr *ipv6addrp, uint32_t *typeinfo2p);
+extern void ipv6addr_settype(ipv6calc_ipv6addr *ipv6addrp, int flag_reset);
 
 extern int  addr_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
 extern int  addrliteral_to_ipv6addrstruct(const char *addrstring, char *resultstring, const size_t resultstring_length, ipv6calc_ipv6addr *ipv6addrp);
@@ -419,7 +429,7 @@ extern int ipv6addr_iidrandomdetection(const ipv6calc_ipv6addr *ipv6addrp, s_iid
 
 extern int  ipv6addr_filter(const ipv6calc_ipv6addr *ipv6addrp, const s_ipv6calc_filter_ipv6addr *filter);
 extern int  ipv6addr_filter_parse(s_ipv6calc_filter_ipv6addr *filter, const char *token);
-extern int  ipv6addr_filter_check(s_ipv6calc_filter_ipv6addr *filter);
+extern int  ipv6addr_filter_check(const s_ipv6calc_filter_ipv6addr *filter);
 extern void ipv6addr_filter_clear(s_ipv6calc_filter_ipv6addr *filter);
 
 extern int  libipv6addr_get_included_ipv4addr(const ipv6calc_ipv6addr *ipv6addrp, ipv6calc_ipv4addr *ipv4addrp, const int selector);
